@@ -1,29 +1,27 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef DESKTOPFILEPAGE_H
 #define DESKTOPFILEPAGE_H
 
-#include <QWidget>
 #include "grantleethemeeditor_export.h"
+#include <QWidget>
 class QLineEdit;
 class KZip;
 class KEditListWidget;
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class PlainTextEditorWidget;
 }
-namespace GrantleeThemeEditor {
+namespace GrantleeThemeEditor
+{
 class GRANTLEETHEMEEDITOR_EXPORT DesktopFilePage : public QWidget
 {
     Q_OBJECT
 public:
-    enum DesktopFileOption {
-        None = 1,
-        ExtraDisplayVariables = 2,
-        SpecifyFileName = 4
-    };
+    enum DesktopFileOption { None = 1, ExtraDisplayVariables = 2, SpecifyFileName = 4 };
     Q_DECLARE_FLAGS(DesktopFileOptions, DesktopFileOption)
 
     explicit DesktopFilePage(const QString &defaultFileName, DesktopFilePage::DesktopFileOptions options, QWidget *parent = nullptr);
